package org.davic.media;



/**

 * This interface describes the methods to handle the Stream events.

 */



public interface StreamEventControl extends javax.media.Control

{

	/**

	 * This method allows the application to subscribe itself to the stream events that are present 

	 * in the current stream. The method requires an event name as input and will return the

	 * associated event identifier. The scope of the event identifier is at least the media stream.

	 *

	 * @param l the listener to be notified when stream events happen

	 * @param eventName the name of the event to listen for

	 * @return the associated event identifier

	 * @exception InvalidEventNameException if the supplied event name cannot be resolved

	 */

	public int subscribeStreamEvent(StreamEventListener l, String eventName) 

		throws InvalidEventNameException;

	/**

          * This method allows the application to subscribe itself to the

          * stream events that are present in the current stream. The method

          * requires an event id as input. The scope of the event identifier

          * is at least the media stream.

          *

          * @param l the listener to be notified when stream events happen

          * @param eventId the id of the event to listen for

          * @exception InvalidEventIDException if the supplied event id is

          * invalid.

          */

         public void subscribeStreamEvent(StreamEventListener l, int eventId) 

         	throws InvalidEventIDException;



	/** 

	 * This method allows the application to unsubscribe itself from stream events that are 

	 * present in the current stream. 

	 * 

	 * @param l the listener to un-subscribe

	 * @param id the event id of the events that the listener is no longer interested in

	 * @exception InvalidEventIDException If the supplied identification does not exist or the

	 * application has not subscribed to this event

	 */

	public void unsubscribeStreamEvent(StreamEventListener l, int id)

		throws InvalidEventIDException;



	/**

	 * This method allows the application to get a list of available stream event names.

	 * @return a list of available stream event names

	 */

	public String[] getEventList();

}






